/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is SearchPluginHacks Mozilla Firefox Extension.
 * The Initial Developer of the Original Code is 
 *     Alex Sirota <alex@elbrus.com>. 
 * Portions created by Alex Sirota are Copyright (C) 2005 Alex Sirota. 
 * All Rights Reserved.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

function SearchPluginsHacks() {
}

SearchPluginsHacks.prototype = {

  getFileFromURLSpec : function(url) {
     const nsIFileProtocolHandler = Components.interfaces.nsIFileProtocolHandler;
     var handler = Components.classes["@mozilla.org/network/protocol;1?name=file"].
                    createInstance();
     handler = handler.QueryInterface(nsIFileProtocolHandler);
     return handler.getFileFromURLSpec(url);
  },

  getLocaleString : function(strName, formattingValues) {
	var str = null;
	try {
		var strbundle = document.getElementById("searchpluginshacks-strings");
		if (formattingValues === undefined) {
			str = strbundle.getString(strName);
		} else {
			str = strbundle.getFormattedString(strName, formattingValues);
		}
	} catch (err) {
		dump("Couldn't get string: " + strName + "\n");
	}
	return str;
  },

  init : function() {
    var searchbar = document.getElementById('searchbar');
    var elem = document.getAnonymousElementByAttribute (searchbar, 'anonid', 'searchbar-popup');
//    Sort:
//    elem.setAttribute('sortResource', "http://home.netscape.com/NC-rdf#Name");
//    elem.setAttribute("sortDirection","ascending");
//    elem.builder.rebuild();
      menuItems = elem.getElementsByTagName('menuitem');
      for (i = 0; i < menuItems.length; i++) {
          menuItems[i].setAttribute('context', 'sph-menupopup');
      }

  },

  deleteFile : function (fileName) {
    var file  = Components.classes["@mozilla.org/file/local;1"].
                                createInstance(Components.interfaces.nsILocalFile);
	file.initWithPath(fileName);
    file.remove(false);
  },

  contextMenuHidden : function (event) {
    var popupNode = document.popupNode;
    popupNode.parentNode.hidePopup();
  },

  deletePlugin : function (event) {
    event.target.parentNode.hidePopup();

    var popupNode = document.popupNode;
    popupNode.parentNode.hidePopup();
    var name       = popupNode.label;
    var pluginFile = unescape(popupNode.value);
    var imageFile  = unescape(popupNode.getAttribute('src'));

    if (pluginFile.substring(0, 9) == 'engine://') {
       pluginFile = pluginFile.substring(9);
    } else {
       //TBD: print warning
       return;
    }

    if (imageFile.substring(0, 8) != 'file:///') {
       //TBD: print warning
       return;
    }

    // convert to native path spec: 
    imageFile = this.getFileFromURLSpec(imageFile).path;

    var prompter = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].
                    getService(Components.interfaces.nsIPromptService);
    var result = prompter.confirm(window, 
                                    this.getLocaleString('delete'), 
                                    this.getLocaleString('deletePluginPrompt', 
                                                        [name, pluginFile, imageFile]));
    if (!result) {
        return;
    }

    this.deleteFile(pluginFile);
    this.deleteFile(imageFile);

//    var deletedId = popupNode.getAttribute('id');
//    if (deletedId == popupNode.parentNode.parentNode.parentNode.currentEngine) {
//    }

    popupNode.parentNode.removeChild(popupNode); 

  },
}

var gSearchPluginsHacks = new SearchPluginsHacks();
addEventListener("load", gSearchPluginsHacks.init, false);
